AdaptiveBreakpoints class

Configurable breakpoints for adaptive layouts.

Allows customizing the screen size thresholds used by AdaptiveLayout instead of using the default Material Design breakpoints.

Constructors

AdaptiveBreakpoints({double compact = 600, double medium = 840, double expanded = 1200, double large = 1200})
const

Properties

compact double
The maximum width for compact layout.
final
expanded double
The maximum width for expanded layout.
final
hashCode int
The hash code for this object.
no setterinherited
large double
The minimum width for large layout.
final
medium double
The maximum width for medium layout.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getScreenType(double width) ScreenType
Determines the screen type for a given width.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

dense → const AdaptiveBreakpoints
Smaller breakpoints for denser layouts.
material → const AdaptiveBreakpoints
Material Design 3 breakpoints (default).
spacious → const AdaptiveBreakpoints
Larger breakpoints for spacious layouts.
tablet → const AdaptiveBreakpoints
Custom breakpoints for tablets.